@@ -3,6 +3,7 @@ import json
 import yaml
 from .hyperdata_client import HyperdataHttpClient, HyperdataUserAuth
 from time import sleep
+import uuid
 
 
 class PreCheck:
@@ -116,8 +117,9 @@ class PreCheck:
             if data["name"] == self.train_do_name:
                 res = self.hyperdata_client.get_do_detail_info(self.auth, data["id"])
                 data_columns = [col_info["name"] for col_info in res.data["dto"]["colInfoList"]]
-                if (len(data_columns) == len(self.train_input_columns) and
-                        len(list(set(data_columns) & set(self.train_input_columns))) == len(data_columns)):
+                if len(data_columns) == len(self.train_input_columns) and len(
+                    list(set(data_columns) & set(self.train_input_columns))
+                ) == len(data_columns):
                     print("check is train do exist end.\n")
                     self.train_do_id = data["id"]
                     return
@@ -145,8 +147,9 @@ class PreCheck:
             if data["name"] == self.inference_do_name:
                 res = self.hyperdata_client.get_do_detail_info(self.auth, data["id"])
                 data_columns = [col_info["name"] for col_info in res.data["dto"]["colInfoList"]]
-                if (len(data_columns) == len(self.inference_input_columns) and
-                        len(list(set(data_columns) & set(self.inference_input_columns))) == len(data_columns)):
+                if len(data_columns) == len(self.inference_input_columns) and len(
+                    list(set(data_columns) & set(self.inference_input_columns))
+                ) == len(data_columns):
                     print("check is inference do exist end.\n")
                     self.inference_do_id = data["id"]
                     return
@@ -262,18 +265,11 @@ class PredefinedAITemplateTest:
             },
         }
         """
+        create_experiment_data["name"] = create_experiment_data["model"] + str(uuid.uuid4())
         res = requests.get(experiment_url, headers=self.request_header)
         if res.status_code != 200:
             raise Exception(f"Get experiment info failed. " f"reason: {res.text}")
 
-        experiment_infos = json.loads(res.text)
-        for experiment_info in experiment_infos:
-            if experiment_info["name"] == create_experiment_data["name"]:
-                raise Exception(
-                    f"Experiment Name {create_experiment_data['name']} already exists. "
-                    f"Please change experiment name or delete experiment",
-                )
-
         print(
             "send create experiment request to automl server. After creating experiments,"
             + "training will start."
